StepProgress class

Inheritance

Constructors

StepProgress({Key? key, required int currentStep, required int totalSteps, required dynamic onNext(int), required dynamic onBack(int), required dynamic onFinish(), String activeColor = "00FF00", String inactiveColor = "808080", String backButtonColor = "000000", String continueButtonColor = "00FF00", String finishButtonColor = "0000FF", double buttonHeight = 50.0, bool enableFinishButtonGlow = true, EdgeInsets padding = const EdgeInsets.symmetric(horizontal: 16)})
const

Properties

activeColor String
final
backButtonColor String
final
buttonHeight double
final
continueButtonColor String
final
currentStep int
final
enableFinishButtonGlow bool
final
finishButtonColor String
final
hashCode int
The hash code for this object.
no setterinherited
inactiveColor String
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onBack → dynamic Function(int)
final
onFinish → dynamic Function()
final
onNext → dynamic Function(int)
final
padding EdgeInsets
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalSteps int
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _StepProgressState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited